CNotifySdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CNotifySdkPlatform
Implementers

Constructors

CNotifySdkPlatform()
Constructs a FlutterCnotifySdkPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({String? googleServiceInfoPlistPathOverride, bool testing = false}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CNotifySdkPlatform
The default instance of CNotifySdkPlatform to use.
getter/setter pair